@@ -6,17 +6,17 @@ class JoinOperator(Operator):
     TAGS = [ "join" ]
     def construct(self):
         # inputs
-        self.input_1 = self.register_input('Input 1')
-        self.input_2 = self.register_input('Input 2')
+        self.input_1 = self.register_input('Input 1', on_change = self.update_output)
+        self.input_2 = self.register_input('Input 2', on_change = self.update_output)
         # outputs
         self.output = self.register_output('Joined data')
         # parameters
         self.column_param_1 = self.register_parameter(
-                'NUMERIC_COLUMN_SELECTION', 'input column 1', self.input_1)
-        self.column_param_1.on_change.subscribe(self.update_output)
+                'NUMERIC_COLUMN_SELECTION', 'input column 1', self.input_1,
+                on_change = self.update_output)
         self.column_param_2 = self.register_parameter(
-                'NUMERIC_COLUMN_SELECTION', 'input column 2', self.input_2)
-        self.column_param_2.on_change.subscribe(self.update_output)
+                'NUMERIC_COLUMN_SELECTION', 'input column 2', self.input_2,
+                on_change = self.update_output)
 
     def update_output(self):
         input_col_1 = self.column_param_1.column
