@@ -1,20 +1,21 @@
+import gevent
+from gevent.lock import Semaphore
 from sakura.common.io import pack, ORIGIN_ID
 from sakura.common.tools import ObservableEvent, MonitoredList
 from sakura.daemon.processing.plugs.input import InputPlug
 from sakura.daemon.processing.plugs.output import OutputPlug
 from sakura.daemon.processing.tab import Tab
 from sakura.daemon.processing.parameter import instanciate_parameter
-from gevent.lock import Semaphore
 
 class Operator:
     IGNORED_FILENAMES = ("__pycache__", ".DS_Store")
-    def __init__(self, op_id, hub_event_recorder, op_dir):
+    def __init__(self, op_id, hub_events_recorder, op_dir):
         self.op_id = op_id
         self.root_dir = op_dir
         self.event_lock = Semaphore()
-        self._last_sources_origins = (None, None)
-        self.pending_move_check = False
-        self.hub_event_recorder = hub_event_recorder
+        self.hub_events_recorder = hub_events_recorder
+        self.hub_events = []
+        self.flushing_hub_events = False
         self.input_plugs = MonitoredList()
         self.input_plugs.on_change.subscribe(lambda: self.push_event_to_hub('altered_set_of_inputs'))
         self.output_plugs = MonitoredList()
@@ -26,9 +27,27 @@ class Operator:
         self.opengl_apps = MonitoredList()
         self.opengl_apps.on_change.subscribe(lambda: self.push_event_to_hub('altered_set_of_opengl_apps'))
         self.check_mode = False
+    def flush_hub_events(self):
+        # retrieve events and reinit for next time
+        all_events = self.hub_events
+        self.hub_events = []
+        self.flushing_hub_events = False
+        # drop duplicated events, keep only the last one
+        seen_events = set()
+        events = []
+        for evt, args, kwargs in reversed(all_events):
+            hashable_event = (evt, args, tuple(kwargs.items()))
+            if hashable_event not in seen_events:
+                events.append((evt, args, kwargs))
+                seen_events.add(hashable_event)
+        # publish to hub
+        self.hub_events_recorder(tuple(reversed(events)))
     def push_event_to_hub(self, evt, *args, **kwargs):
         if not self.check_mode:
-            self.hub_event_recorder(evt, *args, **kwargs)
+            self.hub_events.append((evt, args, kwargs))
+            if not self.flushing_hub_events:
+                self.flushing_hub_events = True
+                gevent.spawn(self.flush_hub_events)
     def notify_input_plug_change(self, in_plug):
         if self.check_mode:
             return
@@ -41,30 +60,17 @@ class Operator:
         # send notification targetting the link mixin object on hub
         if in_plug.source is None:
             print(self.op_id, 'input_now_none')
-            self.push_event_to_hub('input_now_none', in_plug_id)
+            self.push_event_to_hub('hub:input_now_none', in_plug_id)
         else:
             print(self.op_id, 'input_no_longer_none')
-            self.push_event_to_hub('input_no_longer_none', in_plug_id)
+            self.push_event_to_hub('hub:input_no_longer_none', in_plug_id)
+            self.move()
     def notify_output_plug_change(self, out_plug):
         self.push_event_to_hub('altered_output', self.output_plugs.index(out_plug))
+        if out_plug.source is not None:
+            self.move()
     def notify_parameter_change(self, param):
         self.push_event_to_hub('altered_parameter', self.parameters.index(param))
-    @property
-    def _sources_origins(self):
-        inputs_origins, outputs_origins = (), ()
-        for in_plug in self.input_plugs:
-            if in_plug.enabled:
-                inputs_origins += (in_plug.source.get_origin_id(),)
-            else:
-                inputs_origins += (None,)
-        for out_plug in self.output_plugs:
-            if out_plug.enabled:
-                outputs_origins += (out_plug.source.get_origin_id(),)
-            else:
-                outputs_origins += (None,)
-        return inputs_origins, outputs_origins
-    def _trigger_env_affinity_update(self):
-        return self._sources_origins != self._last_sources_origins
     # static properties
     def register_input(self, input_plug_label, required = True, on_change = None):
         return self.register(self.input_plugs,
@@ -125,12 +131,6 @@ class Operator:
                 if not param.check_input_compatible():
                     return False
         return True
-    def unselect_parameters(self, plug = None):
-        for param in self.parameters:
-            # restrict to parameters concerning the specified plug if any
-            if plug != None and not param.is_linked_to_plug(plug):
-                continue
-            param.unset_value()
     def serve_file(self, request):
         return request.serve(str(self.root_dir))
     def get_file_content(self, file_path):
@@ -189,20 +189,19 @@ class Operator:
             return self.handle_event(*args, **kwargs)
     def set_check_mode(self, check_mode):
         self.check_mode = check_mode
-    def env_affinity(self):
-        self._last_sources_origins = self._sources_origins
-        inputs_origins, outputs_origins = self._last_sources_origins
-        affinity = 0
-        # add 3 points per input source on this daemon
-        affinity += 3 * sum(map(lambda x: x == ORIGIN_ID, inputs_origins))
-        # add 1 point per output source on this daemon
-        affinity += 1 * sum(map(lambda x: x == ORIGIN_ID, outputs_origins))
-        return affinity
     def move(self):
-        self.pending_move_check = True
-    def pop_pending_move_check(self):
-        if self.is_ready() and self.pending_move_check:
-            self.pending_move_check = False     # clear for next request
-            return True
-        else:
-            return False
+        if self.is_ready():
+            self.push_event_to_hub('hub:check_move')
+    def get_plug_origins(self):
+        inputs_origins, outputs_origins = (), ()
+        for in_plug in self.input_plugs:
+            if in_plug.enabled:
+                inputs_origins += (in_plug.source.get_origin_id(),)
+            else:
+                inputs_origins += (None,)
+        for out_plug in self.output_plugs:
+            if out_plug.enabled:
+                outputs_origins += (out_plug.source.get_origin_id(),)
+            else:
+                outputs_origins += (None,)
+        return inputs_origins, outputs_origins
