@@ -7,12 +7,12 @@ var cursorX;
 var cursorY;
 
 
-var instances_waiting_for_creation = [];
-var waiting_gui = null;
+// var instances_waiting_for_creation = [];
+// var waiting_gui = null;
 
 var LOG_INTERACTION_EVENT   = false;
 var LOG_DATAFLOW_EVENTS     = true;
-var LOG_LINKS_EVENTS        = false;
+var LOG_LINKS_EVENTS        = true;
 var LOG_OPERATORS_EVENTS    = true;
 
 document.onmousemove = function(e){
