@@ -17,6 +17,7 @@ var transparent_grey = 'rgba(200, 200, 200, 1)';
 var dataflows_operators_debug = false;
 
 function operators_deal_with_events(evt_name, args, proxy, hub_inst_id) {
+    if (LOG_OPERATORS_EVENTS) { console.log('OP EVENT', evt_name, args, proxy, hub_inst_id);}
     switch (evt_name) {
         case 'altered_output':
             if (! op_reloading) {
@@ -27,89 +28,58 @@ function operators_deal_with_events(evt_name, args, proxy, hub_inst_id) {
                         fill_in_out('output', 'op_'+op.cls_id+'_'+hub_inst_id);
                     }
                 }).catch ( function (error) {
+                    pop_request('operators_info');
                     console.log('OPERATORS.js: error 1', error);
                 });
             }
             break;
 
         case 'enabled':
-            if (LOG_OPERATORS_EVENTS) { console.log('ENABLED OP', args, hub_inst_id); }
+            push_request('operators_info');
+            proxy.info().then( function (opi) {
+                pop_request('operators_info');
+                update_operator_instance_from_hub(opi.cls_id, opi);
 
-            let inst_index = -1;
-
-            for (let i=0; i< instances_waiting_for_creation.length; i++) {
-                if  (instances_waiting_for_creation[i].id == hub_inst_id) {
-                    inst_index = i;
-                }
-            };
-
-            //console.log('INST', instances_waiting_for_creation[inst_index]);
-
-            if ( inst_index != -1) {
-                let proxy = sakura.apis.hub.operators[hub_inst_id];
-                let g = { x: instances_waiting_for_creation[inst_index].gui.x,
-                          y: instances_waiting_for_creation[inst_index].gui.y
-                        }
-                push_request('operators_set_gui_data');
-                proxy.set_gui_data(JSON.stringify(g)).then( function() {
-                    pop_request('operators_set_gui_data');
-                    push_request('operators_info');
-                    proxy.info().then( function (opi) {
-                        pop_request('operators_info');
-                        create_operator_instance_from_hub(g.x,
-                                                          g.y,
-                                                          opi.cls_id, opi);
-                        check_operator(opi);
-                    }).catch ( function (error) {
-                        pop_request('operators_info');
-                        console.log('OPERATORS.js: error 2', error);
-                    });
-                }).catch ( function (error) {
-                    pop_request('operators_set_gui_data');
-                    console.log('OPERATORS.js: error 3', error);
-                });
-
-                //remove from waiting list
-                instances_waiting_for_creation.pop(inst_index);
-            }
-            else {
-                let proxy = sakura.apis.hub.operators[hub_inst_id];
-                push_request('operators_info');
-                proxy.info().then( function (opi) {
-                    pop_request('operators_info');
-                    update_operator_instance_from_hub(opi.cls_id, opi);
-
-                    push_request('dataflows_info');
-                    sakura.apis.hub.dataflows[web_interface_current_id].info().then(function (df_info) {
-                        for (let i=0; i< df_info.links.length; i++) {
-                            if (opi.op_id == df_info.links[i].src_id ||
-                                opi.op_id == df_info.links[i].dst_id) {
-                                let found = false;
-                                for (let l=0; l<global_links.length;l++) {
-                                    if (global_links[l].src ==  df_info.links[i].src_id &&
-                                        global_links[l].dst ==  df_info.links[i].dst_id ) {
-                                        found = true;
-                                    }
-                                }
-                                if (!found) {
-                                    create_dataflow_links([df_info.links[i]], true);
+                push_request('dataflows_info');
+                sakura.apis.hub.dataflows[web_interface_current_id].info().then(function (df_info) {
+                    for (let i=0; i< df_info.links.length; i++) {
+                        if (opi.op_id == df_info.links[i].src_id ||
+                            opi.op_id == df_info.links[i].dst_id) {
+                            let found = false;
+                            for (let l=0; l<global_links.length;l++) {
+                                if (global_links[l].src ==  df_info.links[i].src_id &&
+                                    global_links[l].dst ==  df_info.links[i].dst_id ) {
+                                    found = true;
                                 }
                             }
+                            if (!found) {
+                                create_dataflow_links([df_info.links[i]], true);
+                            }
                         }
-                        pop_request('dataflows_info');
-                    }).catch(function(error) {
-                        pop_request('dataflows_info');
-                    });
-                    check_operator(opi);
-                }).catch ( function (error) {
-                    pop_request('operators_info');
-                    console.log('OPERATORS.js: error 5', error);
+                    }
+                    pop_request('dataflows_info');
+                }).catch(function(error) {
+                    pop_request('dataflows_info');
                 });
-            }
+                check_operator(opi);
+            }).catch ( function (error) {
+                pop_request('operators_info');
+                console.log('OPERATORS.js: error 2', error);
+            });
             break;
 
         case 'disabled':
-            if (LOG_OPERATORS_EVENTS) { console.log('DISABLED OP', args, proxy, hub_inst_id);}
+            push_request('operators_info');
+            sakura.apis.hub.operators[hub_inst_id].info().then( function(op) {
+                pop_request('operators_info');
+                check_operator(op);
+            }).catch ( function (error) {
+                pop_request('operators_info');
+                console.log('OPERATORS.js: error 3, event: ', evt_name, ', ', error);
+            });
+            break;
+
+        case 'altered_parameter':
             push_request('operators_info');
             sakura.apis.hub.operators[hub_inst_id].info().then( function(op) {
                 pop_request('operators_info');
@@ -121,23 +91,25 @@ function operators_deal_with_events(evt_name, args, proxy, hub_inst_id) {
             break;
 
         default:
-            if (LOG_OPERATORS_EVENTS) { console.log('OP EVENT', evt_name, args, proxy, hub_inst_id);}
+            if (LOG_OPERATORS_EVENTS) { console.log('--->UNMANAGED OP EVENT', evt_name );}
             push_request('operators_info');
             sakura.apis.hub.operators[hub_inst_id].info().then( function(op) {
                 pop_request('operators_info');
                 check_operator(op);
             }).catch ( function (error) {
                 pop_request('operators_info');
-                console.log('OPERATORS.js: error 4, event: ', evt_name, ', ', error);
+                console.log('OPERATORS.js: error 5, event: ', evt_name, ', ', error);
             });
     }
 }
 
 function create_operator_instance_on_hub(drop_x, drop_y, id) {
-    waiting_gui = {x: drop_x, y: drop_y}
+    gui_data = {x: drop_x, y: drop_y}
     //We first send the creation command to the sakura hub
     push_request('operators_create');
-    sakura.apis.hub.operators.create(web_interface_current_id, parseInt(id)).then(function (result) {
+    sakura.apis.hub.operators.create( web_interface_current_id,
+                                      parseInt(id),
+                                      {'gui_data': JSON.stringify(gui_data)}).then(function (result) {
         pop_request('operators_create');
     }).catch( function (error){
         pop_request('operators_create');
@@ -145,7 +117,6 @@ function create_operator_instance_on_hub(drop_x, drop_y, id) {
     });
 }
 
-
 function create_operator_instance_from_hub(drop_x, drop_y, id, info) {
     let ndiv = select_op_new_operator(id, false );
 
@@ -234,7 +205,7 @@ function create_op_plugs(info, ndiv) {
                                                 id: id_i,
                                                 cssClass:"sakura_endPoint",
                                                 paintStyle:{fillStyle:"black", radius:6},
-                                                hoverPaintStyle:{ fillStyle:"black", radius:10}
+                                                hoverPaintStyle:{ fillStyle:"black", radius:6}
                                                 });
     }
     if (info.outputs.length > 0 && !endpoint_exists(id_o))
@@ -318,7 +289,9 @@ function check_operator(op) {
             w_div = document.getElementById(id+"_warning");
             w_div.style.visibility  = "hidden";
         }
-        check_output(op);
+        //check_output(op);
+        output_disable(inst);
+        input_disable(inst);
     }
 }
 
@@ -487,14 +460,11 @@ function output_enable(inst) {
     if (inst.ep.out) {
         inst.ep.out.isSource = true;
         inst.ep.out.setPaintStyle({fillStyle: 'black', radius: 6});
-        inst.ep.out.setHoverPaintStyle({fillStyle: 'black', radius: 10});
+        inst.ep.out.setHoverPaintStyle({fillStyle: 'black', radius: 6});
 
         for (let i=0;i<global_links.length;i++) {
             if (global_links[i].src == inst.hub_id) {
-                global_links[i].jsP.setPaintStyle({strokeStyle: 'black',
-                                                  lineWidth: 3});
-                global_links[i].jsP.setHoverPaintStyle({strokeStyle: 'black',
-                                                        lineWidth: 7});
+                enable_link(global_links[i]);
             }
         }
 
@@ -510,13 +480,23 @@ function output_disable(inst) {
 
         for (let i=0;i<global_links.length;i++) {
             if (global_links[i].src == inst.hub_id) {
-                global_links[i].jsP.setPaintStyle({strokeStyle: transparent_grey,
-                                                  lineWidth: 3});
-                global_links[i].jsP.setHoverPaintStyle({strokeStyle: transparent_grey,
-                                                        lineWidth: 4});
+                disable_link(global_links[i]);
             }
         }
+        jsPlumb.repaintEverything();
+    }
+}
 
+function input_disable(inst) {
+    if (inst.ep.in) {
+        inst.ep.in.setPaintStyle({fillStyle: transparent_grey, radius: 6});
+        inst.ep.in.setHoverPaintStyle({fillStyle: transparent_grey, radius: 6});
+
+        for (let i=0;i<global_links.length;i++) {
+            if (global_links[i].src == inst.hub_id) {
+                disable_link(global_links[i]);
+            }
+        }
         jsPlumb.repaintEverything();
     }
 }
